==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/audio/audio.h <==
/*
 *  Copyright (C) 2006-2009 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef AUDIO_OUTPUT_H
#define AUDIO_OUTPUT_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <fx.h>

#ifdef HAVE_BS2B
#  include <bs2b.h>
#endif

#include "input.h"
#include "output.h"
#include "converterFactory.h"

/*****************************************************************/

class audioThread;

/*****************************************************************/

enum state_t { STOP, PLAY, PAUSE };
enum msg_t { PRELOAD_SONG, SONG_ENDED, UPD_TIME, OUTPUT_ERROR };

class audio {

	friend class audioThread;

private:
	input		*_input;
	input		*_preload;
	output		*_output;

	state_t		_state;
	bool		_playing;

	audioThread	*_thread;

	size_t		_bufferSize;

	int 		_buffers;
	int 		_bufPerSec;
	int		_seconds;

	FXGUISignal	*_guiMsg;

	int		_volume;

	converter	*_converter;
#ifdef HAVE_BS2B
	t_bs2bdp	_bs2bdp;
#endif
private:
	audio() {};
	audio(const audio&);
	audio& operator=(const audio&);

	sample_t outputPrecision();

	template<typename T>
	void elaborate(size_t size);

	///
	template<typename T>
	void loop();

public:
	audio(FXObject *o, FXSelector guiMsg);
	~audio();

	/// Set options
	void setOpts();

	/// Start stream
	bool play(input* i);

	/// Pause stream
	void pause();

	/// Stop stream
	bool stop();

	/// Get state
	state_t state() const { return _state; }

	/// Get seconds
	FXint seconds() const { return _seconds; }

	/// Set volume
	void volume(const int vol);

	/// Get volume
	int volume() { return _volume; }

	/// Check if gapless playback is supported
	bool gapless(input* const i);
};

/*****************************************************************/

#include "configFrame.h"

class audioConfig : public configFrame {
	FXDECLARE(audioConfig)
private:
	FXListBox	*_apiList;
	FXListBox	*_cardList;

private:
	audioConfig() {};
	audioConfig(const audioConfig&);
	audioConfig& operator=(const audioConfig&);

	void setCards(const output* const audio);

public:
	audioConfig(FXComposite* win);
	virtual ~audioConfig() {};

public:
	enum {
		ID_API=FXDialogBox::ID_LAST,
		ID_CARD,
		ID_BITS,
		ID_LAST,
	};

public:
	long onCmdApi(FXObject*, FXSelector, void*);
	long onCmdCard(FXObject*, FXSelector, void*);
	long onCmdBits(FXObject*, FXSelector, void*);
};

/*****************************************************************/

class audioThread : public FXThread {
private:
	audio	*_audio;

protected:
	FXint run();

public:
	audioThread(audio* a)
		: FXThread(), _audio(a) {};
	~audioThread() {};
};

#endif

==> fap-0.9.2.tar.bz2: fap-0.9.2/src/audio/audio.h <==
/*
 *  Copyright (C) 2006-2009 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef AUDIO_OUTPUT_H
#define AUDIO_OUTPUT_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <fx.h>

#ifdef HAVE_BS2B
#  include <bs2b.h>
#endif

#include "inputTypes.h"

class input;
class output;
class converter;

/*****************************************************************/

class audioThread;

/*****************************************************************/

enum state_t { STOP, PLAY, PAUSE };
enum msg_t { PRELOAD_SONG, SONG_ENDED, UPD_TIME, OUTPUT_ERROR };

class audio {

	friend class audioThread;

private:
	input		*_input;
	input		*_preload;
	output		*_output;

	state_t		_state;
	bool		_playing;

	audioThread	*_thread;

	size_t		_bufferSize;

	int 		_buffers;
	int 		_bufPerSec;
	int		_seconds;

	FXGUISignal	*_guiMsg;

	int		_volume;

	converter	*_converter;
#ifdef HAVE_BS2B
	t_bs2bdp	_bs2bdp;
#endif
private:
	audio() {};
	audio(const audio&);
	audio& operator=(const audio&);

	sample_t outputPrecision();

	template<typename T>
	void elaborate(size_t size);

	///
	template<typename T>
	void loop();

public:
	audio(FXObject *o, FXSelector guiMsg);
	~audio();

	/// Set options
	void setOpts();

	/// Start stream
	bool play(input* i, int pos=0);

	/// Pause stream
	void pause();

	/// Stop stream
	bool stop();

	/// Get state
	state_t state() const { return _state; }

	/// Get seconds
	FXint seconds() const { return _seconds; }

	/// Set volume
	void volume(const int vol);

	/// Get volume
	int volume() { return _volume; }

	/// Check if gapless playback is supported
	bool gapless(input* const i);
};

/*****************************************************************/

#include "configFrame.h"

class audioConfig : public configFrame {
	FXDECLARE(audioConfig)
private:
	FXListBox	*_apiList;
	FXListBox	*_cardList;

private:
	audioConfig() {};
	audioConfig(const audioConfig&);
	audioConfig& operator=(const audioConfig&);

	void setCards(const output* const audio);

public:
	audioConfig(FXComposite* win);
	virtual ~audioConfig() {};

public:
	enum {
		ID_API=FXDialogBox::ID_LAST,
		ID_CARD,
		ID_BITS,
		ID_LAST,
	};

public:
	long onCmdApi(FXObject*, FXSelector, void*);
	long onCmdCard(FXObject*, FXSelector, void*);
	long onCmdBits(FXObject*, FXSelector, void*);
};

/*****************************************************************/

class audioThread : public FXThread {
private:
	audio	*_audio;

protected:
	FXint run();

public:
	audioThread(audio* a)
		: FXThread(), _audio(a) {};
	~audioThread() {};
};

#endif
